# Change log of DVHA DICOM Editor

v0.3 (TBD)
--------------------
 - Catch tag edit exceptions, display error log in window
 - Reorganized code so it is easier to follow, lots of comments added
 - Search for DICOM tags
 - Values can be dynamically defined based on file_path or current tag values
 - Thread file parsing with progress bar
 - Ability to search sub folders
 
 
v0.2 (2020.03.27)
--------------------
 - Allow user to select a file to pre-populate the value input
 - Update description key up for more intuitive update
 - Save and load templates
 - Custom prepend string for file names

v0.1 (2020.03.25)
--------------------
 - Initial commit